Changelog for stdlib_utils
==========================

0.3.1 (2020-09-17)
------------------

- Added notebook logging format.


0.3.0 (09-11-20)
------------------

- Added tracking of 5 longest iterations to InfiniteLoopingParallelismMixIn.
